#!/bin/sh

# Function that, when given gsdlpath as parameter, will return the
# version of greenstone that is to run (2 or 3). If things are not,
# this program will exit here.
get_version() {
    # first parameter is value of gsdlpath
    if [ -f "${1}/gs3-setup.sh" ]; then
	return 3
    elif [ -f "${1}/setup.bash" ]; then
	return 2
    else
	echo "Error: can't determine which Greenstone version is being run."
	exit 1
    fi
}

# Function that is passed the following paramters (in order):
# - the gsdlpath (GS3 home, GS2 home or gs2build for GS3), 
# - the version of greenstone that's running, and 
# - the language GLI is set to
# and checks the installation. 
# If things are not right, this program will exit here.
check_installation() {
# Check that the Greenstone installation looks OK
    if [ "$3" = "es" ]; then
	echo "Revisando GSDL$2: $1"
    elif [ "$3" = "fr" ]; then
	echo "Vrification de GSDL$2: $1"
    elif [ "$3" = "ru" ]; then
	echo " GSDL$2: $1"
    else
	echo "Checking GSDL$2: $1"
    fi
    # even if we are only checking for gs2build (gsdl2path), we still 
    # need the file setup.bash to exist in the following condition:
    if [ ! -f "${1}/gs3-setup.sh" -a ! -f "${1}/setup.bash" ] ; then
	echo
	if [ "$3" = "es" ]; then
	    echo "No se pudo encontrar la instalacin de Greenstone $2 o est incompleta."
	    echo "Trate de reinstalar Greenstone $2 y a continuacin ejecute nuevamente"
	    echo "este guin."
	elif [ "$3" = "fr" ]; then
	    echo "L'installation de Greenstone $2 est introuvable ou incomplte."
	    echo "Essayez de rinstaller Greenstone $2 et excutez ce script  nouveau."
	elif [ "$3" = "ru" ]; then
	    echo " Greenstone $_version      ."
	    echo "   Greenstone $2,      ."
	else
	    echo "The Greenstone $2 installation could not be found, or is incomplete."
	    echo "Try reinstalling Greenstone $2 then running this script again."
	fi
	exit 1
    fi
}

glilang=en

if [ "$glilang" = "es" ]; then
    PROGNAME="Editar conjuntos de metadatos"
elif [ "$glilang" = "fr" ]; then
    PROGNAME="Editer les jeux de mta-donnes"
elif [ "$glilang" = "ru" ]; then
    PROGNAME="  "
else
    PROGNAME="Greenstone Editor for Metadata Sets"
fi

PROGABBR="GEMS"

PROGNAME_EN="Greenstone Editor for Metadata Sets"


echo
if [ "$glilang" = "es" ]; then
    echo "$PROGNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "GEMS NO INCLUYE ABSOLUTAMENTE NINGUNA GARANTA."
    echo "Para mayor informacin vea los trminos de la licencia en LICENSE.txt"
    echo "Este es un software abierto, por lo que lo invitamos a que lo distribuya de forma gratuita"
elif [ "$glilang" = "fr" ]; then
    echo "$PROGNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "GEMS est fourni sans AUCUNE GARANTIE; pour des dtails, voir LICENSE.txt"
    echo "Ceci est un logiciel libre, et vous tes invit  le redistribuer"
elif [ "$glilang" = "ru" ]; then
    echo "$PROGNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "     ;  .   LICENSE.TXT"
    echo " -         "
else
    echo "$PROGNAME ($PROGABBR)"
    echo "Copyright (C) 2008, New Zealand Digital Library Project, University Of Waikato"
    echo "GEMS comes with ABSOLUTELY NO WARRANTY; for details see LICENSE.txt"
    echo "This is free software, and you are welcome to redistribute it"
fi
echo

##  -------- Run the Greenstone Editor for Metadata Sets --------

# This script must be run from within the directory in which it lives
thisdir=`pwd`
if [ ! -f "${thisdir}/gems.sh" ]; then
    if [ "$glilang" = "es" ]; then
        echo "Este guin deber ejecutarse desde el directorio en el que reside."
    elif [ "$glilang" = "fr" ]; then
	echo "Ce script doit tre excut  partir du rpertoire dans lequel il se trouve."
    elif [ "$glilang" = "ru" ]; then
	echo "      ,    "
    else
	echo "This script must be run from the directory in which it resides."
    fi
    exit 1
fi


##  ---- Determine GSDLHOME ----
## gsdlpath can be either Greenstone 3 or Greenstone 2
gsdlpath=
# Some users may set the above line manually


# This variable is set automatically:
_version=
if [ "x$gsdlpath" != "x" ]; then
    get_version $gsdlpath
    _version=$?
# otherwise $gsdlpath is not yet set
else
    # Check the environment variable first
    # Check whether environment variables for both GS2 and GS3 are set
    # and if so, warn the user that we have defaulted to GS3
    if [ "x$GSDLHOME" != "x" -a "x$GSDL3SRCHOME" != "x" ]; then
        # _version not set, but both env vars set, so default to 3
	_version=3
	gsdlpath=$GSDL3SRCHOME
	echo "Both Greenstone 2 and Greenstone 3 environments are set." 
	echo "It is assumed you want to run Greenstone 3."
	echo "If you want to run Greenstone 2, please unset the"
	echo "environment variable GSDL3SRCHOME before running GLI."
	echo ""
    elif [ "x$GSDL3SRCHOME" != "x" ]; then
	echo "Only gsdl3srchome set"
	gsdlpath=$GSDL3SRCHOME
	_version=3
	echo "$gsdlpath"
    elif [ "x$GSDLHOME" != "x" ]; then
	gsdlpath=$GSDLHOME
	_version=2
    # If it is not set, assume that the GLI is installed as a subdirectory of Greenstone
    else
	gsdlpath=`(cd .. && pwd)`
	# Still need to find what version we are running:
	# GS3 main directory contains file gs3-setup.sh, GS2 only setup.bash
	get_version $gsdlpath
	_version=$?
    fi
fi

echo "Greenstone version found: $_version"

# Check that the main Greenstone installation for the version we're running looks OK
check_installation $gsdlpath $_version $glilang


# Need to source the correct setup file depending on whether we are running
# gs3 or gs2
# If we're running version GS2
if [ "$_version" -eq 2 ]; then
    # Setup Greenstone 2, unless it has already been done
    if [ "x$GSDLHOME" = "x" ]; then
	cd "$gsdlpath"
	. setup.bash
	cd "$thisdir"
    fi
# else, if we're running GS3
elif [ "$_version" -eq 3 ]; then
    # Setup Greenstone 3, unless it has already been done
    if [ "x$GSDL3HOME" = "x" -o "x$GSDL3SRCHOME" = "x" ]; then
	cd "$gsdlpath"
	. gs3-setup.sh
	cd "$thisdir"
    fi
    
    ## if Greenstone version 3 is running, we want to set gsdl2path
    ##  ---- Determine GSDLHOME ----
    ## may be already set, or manually entered here.
    gsdl2path=
    
    # Some users may set the above line manually
    if [ "x$gsdl2path" = "x" ]; then
        # Check the environment variable first
	if [ "x$GSDLHOME" != "x" ]; then
	    echo "GSDLHOME environment variable is set to $GSDLHOME."
	    echo "Will use this to find build scripts."
	    gsdl2path=$GSDLHOME
        # If it is not set, assume that the gs2build subdirectory of Greenstone 3 exists
	else
	    gsdl2path=$GSDL3SRCHOME/gs2build
	fi
    fi
    # Check that Greenstone 3's Greenstone 2 stuff looks OK (in gs2build)
    check_installation $gsdl2path "" $glilang
  
    # Setup Greenstone 3's gs2build, unless it has already been done
    if [ "x$GSDLHOME" = "x" ]; then
	cd "$gsdl2path"
	. setup.bash
	cd "$thisdir"
    fi

else 
    echo "Greenstone version unknown."    
    exit 1
fi

echo
if [ "x$GSDL3SRCHOME" != "x" ]; then
    echo "GSDL3SRCHOME is: $GSDL3SRCHOME"
fi
if [ "x$GSDL3HOME" != "x" ]; then
    echo "GSDL3HOME is: $GSDL3HOME"
fi
if [ "x$GSDLHOME" != "x" ]; then
    echo "GSDLHOME is: $GSDLHOME"
fi
echo



## ---- Check Java ----
echo "Java:"
MINIMUM_JAVA_VERSION=1.4.0_00

# Some users may set this line manually
#JAVA_HOME=

if [ -z $javapath ]; then

    # sus out search4j
    if [ "$_version" -eq 2 -a -e "$GSDLHOME/bin/$GSDLOS/search4j" ]; then
        SEARCH4J_EXECUTABLE=$GSDLHOME/bin/$GSDLOS/search4j
    elif [ "$_version" -eq 3 -a -e "$GSDL3SRCHOME/bin/$GSDLOS/search4j" ]; then
        SEARCH4J_EXECUTABLE=$GSDL3SRCHOME/bin/search4j
    elif [ -e "../bin/$GSDLOS/search4j" ]; then
        SEARCH4J_EXECUTABLE=../bin/$GSDLOS/search4j
    elif [ -e "../bin/search4j" ]; then
        SEARCH4J_EXECUTABLE=../bin/search4j
    else
        echo "Couldn't determine the location of the search4j executable"
        echo "If you are running Greenstone2"
        echo "   * check GSDLHOME is set"
        echo "   * check bin/$GSDLOS/search4j exists"
        echo "   * check bin/$GSDLOS/search4j is executable"
        echo "If you are running Greenstone3"
        echo "   * check GSDL3SRCHOME is set"
        echo "   * check bin/search4j exists"
        echo "   * check bin/search4j is executable"
        echo "   * try running 'ant compile-search4j'"
    fi

	# Give search4j a hint to find Java depending on the platform
	if [ $GSDLOS = linux ]; then
		HINT=`cd ..;pwd`/packages/jre
	elif [ $GSDLOS = darwin ]; then
		HINT=/System/Library/Frameworks/JavaVM.framework/Home
	fi	
	
    javapath=`$SEARCH4J_EXECUTABLE -e -p $HINT -m $MINIMUM_JAVA_VERSION`

    if [ "$?" != "0" ]; then

        OLDVER=`"$SEARCH4J_EXECUTABLE" -v -p "$HINT"`

        if [ "$?" = "0" ]; then

            if [ "$glilang" = "es" ]; then
                echo "La versin del Ambiente de Ejecucin Java (JRE por sus siglas en "
                echo "ingls) que usted tiene instalada es demasiado vieja para ejecutar "
                echo "la Interfaz de la $PROGNAME. Por favor instale "
                echo "una nueva versin del Ambiente de Ejecucin Java (versin $MINIMUM_JAVA_VERSION o "
                echo "posterior) y ejecute nuevamente este guin."
            elif [ "$glilang" = "fr" ]; then
                echo "La version de Java Runtime Environment que vous avez installe est"
                echo "trop vielle pour faire fonctionner $PROGNAME."
                echo "Veuillez installer une nouvelle version du JRE (version $MINIMUM_JAVA_VERSION ou plus"
                echo "rcente) et redmarrez le script."
            elif [ "$glilang" = "ru" ]; then
                echo " Java Runtime Environment,   ,  ,"
                echo "   $PROGNAME. , "
                echo "   JRE ( $MINIMUM_JAVA_VERSION   ) "
                echo "  "
            else
                echo "The version of the Java Runtime Environment you have installed ($OLDVER)"
                echo "is too old to run the $PROGNAME. Please install a new"
                echo "version of the JRE (version $MINIMUM_JAVA_VERSION or newer) and rerun this script."
            fi
            exit 1

        else

            echo
            if [ "$glilang" = "es" ]; then
                echo "No se pudo localizar una versin apropiada de Java. Usted deber "
                echo "instalar un Ambiente de Ejecucin Java (versin $MINIMUM_JAVA_VERSION o superior) "
                echo "antes de correr la Interfaz de la $PROGNAME."
            elif [ "$glilang" = "fr" ]; then
                echo "Une version adquate de Java n'a pas pu tre localise."
                echo "Vous devez installer un Java Runtime Environment (version $MINIMUM_JAVA_VERSION ou"
                echo "suprieur) avant de dmarrer $PROGNAME."
				echo "Si vous avez Java install sur votre ordinateur veuillez vrifier la variable"
				echo "d'environnement JAVA_HOME."
            elif [ "$glilang" = "ru" ]; then
                echo "      Java."
                echo "   Java Runtime Environment ( $MINIMUM_JAVA_VERSION  )"
                echo "   $PROGNAME."
            else
                echo "Failed to locate an appropriate version of Java. You must install a"
                echo "Java Runtime Environment (version $MINIMUM_JAVA_VERSION or greater) before running the"
                echo "$PROGNAME."
				echo "If you have Java intalled on your machine please set the environment variable JAVA_HOME."
            fi
        fi

    fi

fi
echo $javapath
echo



## ---- Check that the GEMS has been compiled ----
if [ ! -f "classes/org/greenstone/gatherer/gems/GEMS.class" ] && [ ! -f "GLI.jar" ]; then
    echo
    if [ "$glilang" = "es" ]; then
	echo "Usted necesita compilar la $PROGNAME"
	echo "(por medio de makegli.sh) antes de ejecutar este guin."
    elif [ "$glilang" = "fr" ]; then
	echo "Vous devez compiler le $PROGNAME (en utilisant makegli.sh)"
	echo "avant d'excuter ce script."
    elif [ "$glilang" = "ru" ]; then
	echo "   $PROGNAME"
	echo "( makegli.sh)    "
    else
	echo "You need to compile the $PROGNAME (using makegli.sh)"
	echo "before running this script."
    fi
    exit 1
fi

## ---- Finally, run the GEMS ----
echo
if [ "$glilang" = "es" ]; then
    echo "Ejecutando la $PROGNAME..."
elif [ "$glilang" = "fr" ]; then
    echo "Excution de $PROGNAME..."
elif [ "$glilang" = "ru" ]; then
    echo "  $PROGNAME..."
else
    echo "Running the $PROGNAME..."
fi

# Other arguments you can provide to GEMS to work around memory limitations, or debug
# -Xms<number>M    To set minimum memory (by default 32MB)
# -Xmx<number>M    To set maximum memory (by default the nearest 2^n to the total remaining physical memory)
# -verbose:gc      To set garbage collection messages
# -Xincgc          For incremental garbage collection (significantly slows performance)
# -Xprof           Function call profiling
# -Xloggc:<file>   Write garbage collection log

# basic_command is the cmd string common to both Greenstone 3 and Greenstone 2 execution
# (gs3 doesn't -gsdl3src $GSDL3SRCHOME passed to it, it needs $GSDL3HOME to find the collect dir)
basic_command="$javapath -classpath classes/:GLI.jar:lib/apache.jar org.greenstone.gatherer.gems.GEMS"

if [ "$_version" -eq 2 ]; then
    `$basic_command -gsdl $GSDLHOME $*`
elif [ "$_version" -eq 3 ]; then    
    `$basic_command -gsdl3 $GSDL3HOME $*`
fi

    
if [ "$glilang" = "es" ]; then
    echo "Hecho!"
elif [ "$glilang" = "fr" ]; then
    echo "Termin!"
elif [ "$glilang" = "ru" ]; then
    echo "!"
else
    echo "Done!"
fi
